@@ -26,23 +26,20 @@
 #include <QLocale>
 #include <QCache>
 #include <QSet>
-#include <QDebug>
-
-#define MAXLANGUAGES 5
+#include "core_debug.h"
 
 namespace Sonnet
 {
 
-class Speller::Private
+class SpellerPrivate
 {
 public:
-    Private() : dictCache(MAXLANGUAGES), dict(0)
+    SpellerPrivate() : settings(0)
     {
     }
 
-    ~Private()
+    ~SpellerPrivate()
     {
-        // no need to delete dict - dictCache will take care of that
     }
     void init(const QString &lang)
     {
@@ -58,12 +55,7 @@ public:
     }
 
     void updateDict() {
-        if (dictCache.contains(language)) {
-            dict = dictCache.object(language);
-        } else {
-            dict = Loader::openLoader()->createSpeller(language);
-            dictCache.insert(language, dict);
-        }
+        dict = Loader::openLoader()->cachedSpeller(language);
     }
     bool isValid()
     {
@@ -75,31 +67,29 @@ public:
     }
     void recreateDict()
     {
-        dictCache.clear();
+        Loader::openLoader()->clearSpellerCache();
         updateDict();
     }
 
-    QCache<QString,SpellerPlugin> dictCache;
-    SpellerPlugin *dict;
-    Settings      *settings;
-
-    QString        language;
+    QSharedPointer<SpellerPlugin> dict;
+    Settings* settings;
+    QString language;
 };
 
 Speller::Speller(const QString &lang)
-    : d(new Private)
+    : d(new SpellerPrivate)
 {
     d->init(lang);
 }
 
 Speller::~Speller()
 {
-    //qDebug()<<"deleting "<<this;
+    qCDebug(SONNET_LOG_CORE) << "deleting" << this << "for" << d->language;
     delete d;
 }
 
 Speller::Speller(const Speller &speller)
-    : d(new Private)
+    : d(new SpellerPrivate)
 {
     d->language = speller.language();
     d->init(d->language);
@@ -108,7 +98,7 @@ Speller::Speller(const Speller &speller)
 Speller &Speller::operator=(const Speller &speller)
 {
     d->language = speller.language();
-    d->recreateDict();
+    d->updateDict();
     return *this;
 }
 
@@ -213,7 +203,9 @@ QStringList Speller::availableLanguageNames() const
 
 void Speller::setDefaultLanguage(const QString &lang)
 {
-    d->settings->setDefaultLanguage(lang);
+    if (d->settings->setDefaultLanguage(lang)) {
+        d->settings->save();
+    }
 }
 
 QString Speller::defaultLanguage() const
@@ -223,7 +215,9 @@ QString Speller::defaultLanguage() const
 
 void Speller::setDefaultClient(const QString &client)
 {
-    d->settings->setDefaultClient(client);
+    if (d->settings->setDefaultClient(client)) {
+        d->settings->save();
+    }
 }
 
 QString Speller::defaultClient() const
@@ -244,6 +238,7 @@ void Speller::setAttribute(Attribute attr, bool b)
         d->settings->setAutodetectLanguage(b);
         break;
     }
+    d->settings->save();
 }
 
 
